Please take our Survey
logo       

Choosing A Webhost:
A web hosting service is a type of Internet hosting service that allows individuals and organizations to provide their own website accessible via the World Wide Web. Web hosts are companies that provide space on a server they own for use by their clients as well as providing Internet connectivity, typically in a data center. Web hosts can also provide data center space and connectivity to the Internet for servers they do not own to be located in their data center, called colocation. more...

CVS update of carob (9 files): msg#00153

db.carob.cvs

Subject: CVS update of carob (9 files)

Date: Tuesday, January 24, 2006 @ 18:54:51
Author: gilles
Path: /cvsroot/carob/carob

Modified: include/Connection.hpp (1.51 -> 1.52)
include/DriverResultSet.hpp (1.26 -> 1.27)
include/SQLDataSerialization.hpp (1.7 -> 1.8) src/Connection.cpp
(1.58 -> 1.59) src/DriverResultSet.cpp (1.33 -> 1.34)
src/ResultSetMetaData.cpp (1.7 -> 1.8)
src/SQLDataSerialization.cpp (1.15 -> 1.16)
test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp
(1.3 -> 1.4) test/TestBeginCommitRollback.cpp (1.11 -> 1.12)

Removal of useless and unnecessary includes in .hpps (implied forward
declarations)
Reordered includes in .cpp (from most specific to most general)


---------------------------------------------------------------+
include/Connection.hpp | 18 +++++---
include/DriverResultSet.hpp | 9 +---
include/SQLDataSerialization.hpp | 21 ++++------
src/Connection.cpp | 9 ++++
src/DriverResultSet.cpp | 11 +++--
src/ResultSetMetaData.cpp | 1
src/SQLDataSerialization.cpp | 2
test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp | 1
test/TestBeginCommitRollback.cpp | 1
9 files changed, 46 insertions(+), 27 deletions(-)


Index: carob/include/Connection.hpp
diff -u carob/include/Connection.hpp:1.51 carob/include/Connection.hpp:1.52
--- carob/include/Connection.hpp:1.51 Mon Jan 23 17:17:59 2006
+++ carob/include/Connection.hpp Tue Jan 24 18:54:51 2006
@@ -22,15 +22,12 @@
#ifndef _CONNECTION_H_
#define _CONNECTION_H_

-#include <list>
+#include "DriverResultSet.hpp"

-#include "CarobException.hpp"
-#include "ConnectionParameters.hpp"
-#include "ControllerConnectPolicy.hpp"
#include "CriticalSection.hpp"
-#include "DriverResultSet.hpp"
-#include "DriverSocket.hpp"
-#include "RequestWithResultSetParameters.hpp"
+#include "CarobException.hpp"
+
+#include <list>

namespace {
const int32_t ProtocolVersion = ((int32_t) 0/* major */ << 16) + 38/* minor */;
@@ -100,8 +97,15 @@
//#define DatabaseStaticMetadata 80
#define PreparedStatementGetMetaData 81

+class ControllerInfo;
+class DriverSocket;
+class ConnectionParameters;
+class AbstractControllerConnectPolicy;
class Statement;
class ParameterStatement;
+class Request;
+class RequestWithResultSetParameters;
+class DriverResultSet;

/**
* This class implements the communication protocol to the Controller.
Index: carob/include/DriverResultSet.hpp
diff -u carob/include/DriverResultSet.hpp:1.26
carob/include/DriverResultSet.hpp:1.27
--- carob/include/DriverResultSet.hpp:1.26 Wed Jan 18 12:46:14 2006
+++ carob/include/DriverResultSet.hpp Tue Jan 24 18:54:51 2006
@@ -1,6 +1,6 @@
/*
* Sequoia: Database clustering technology.
- * Copyright (C) 2005 Emic Networks
+ * Copyright (C) 2005-2006 Continuent, Inc.
* Contact: sequoia-NAAfj4rwCWAYtQj7fl1lsA@xxxxxxxxxxxxxxxx
*
* Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,12 +22,10 @@
#ifndef DRIVERRESULTSET_H_
#define DRIVERRESULTSET_H_

-#include <vector>
-#include <ext/hash_map>
-
-#include "Field.hpp"
#include "SQLDataSerialization.hpp"

+#include <vector>
+
namespace CarobNS {

/**
@@ -62,6 +60,7 @@

class Statement;
class Connection;
+class Field;
/**
* A <code>ResultSet</code> provides access to a table of data generated by
* executing a Statement. The table rows are retrieved in sequence. Within a
row
Index: carob/src/Connection.cpp
diff -u carob/src/Connection.cpp:1.58 carob/src/Connection.cpp:1.59
--- carob/src/Connection.cpp:1.58 Mon Jan 23 17:17:59 2006
+++ carob/src/Connection.cpp Tue Jan 24 18:54:51 2006
@@ -20,8 +20,17 @@
*/

#include "Connection.hpp"
+
+#include "DriverSocket.hpp"
+#include "ConnectionParameters.hpp"
+#include "ControllerConnectPolicy.hpp"
#include "Statement.hpp"
#include "ParameterStatement.hpp"
+#include "TypeTag.hpp"
+#include "Request.hpp"
+#include "RequestWithResultSetParameters.hpp"
+
+#include <string>

using std::wstring;

Index: carob/src/DriverResultSet.cpp
diff -u carob/src/DriverResultSet.cpp:1.33 carob/src/DriverResultSet.cpp:1.34
--- carob/src/DriverResultSet.cpp:1.33 Tue Jan 24 11:39:05 2006
+++ carob/src/DriverResultSet.cpp Tue Jan 24 18:54:51 2006
@@ -19,14 +19,17 @@
* Contributor(s):
*/

-#include <sstream> //for wostringstream
+#include "DriverResultSet.hpp"

-#include "CarobException.hpp"
-#include "Common.hpp"
#include "Connection.hpp"
-#include "DriverResultSet.hpp"
#include "TypeTag.hpp"
#include "Statement.hpp"
+#include "Field.hpp"
+
+#include "CarobException.hpp"
+#include "Common.hpp"
+
+#include <sstream> //for wostringstream

using std::wstring;
using std::vector;
Index: carob/src/ResultSetMetaData.cpp
diff -u carob/src/ResultSetMetaData.cpp:1.7 carob/src/ResultSetMetaData.cpp:1.8
--- carob/src/ResultSetMetaData.cpp:1.7 Thu Jan 12 18:05:05 2006
+++ carob/src/ResultSetMetaData.cpp Tue Jan 24 18:54:51 2006
@@ -21,6 +21,7 @@

#include "ResultSetMetaData.hpp"

+#include "Field.hpp"
#include "Common.hpp"

using std::wstring;
Index: carob/src/SQLDataSerialization.cpp
diff -u carob/src/SQLDataSerialization.cpp:1.15
carob/src/SQLDataSerialization.cpp:1.16
--- carob/src/SQLDataSerialization.cpp:1.15 Tue Jan 24 11:39:05 2006
+++ carob/src/SQLDataSerialization.cpp Tue Jan 24 18:54:51 2006
@@ -22,6 +22,8 @@
#include "SQLDataSerialization.hpp"

#include "BigDecimal.hpp"
+#include "TypeTag.hpp"
+
#include "CarobException.hpp"
#include "Common.hpp"

Index: carob/test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp
diff -u carob/test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp:1.3
carob/test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp:1.4
--- carob/test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp:1.3
Fri Jan 13 12:53:59 2006
+++ carob/test/40-Parameter-PreparedStatement/TestPreparedStatement.cpp Tue Jan
24 18:54:51 2006
@@ -24,6 +24,7 @@
#include "TestPreparedStatement.hpp"
#include "ParameterStatement.hpp"
#include "ResultSetMetaData.hpp"
+#include "TypeTag.hpp"

using std::wstring;
using std::endl;
Index: carob/test/TestBeginCommitRollback.cpp
diff -u carob/test/TestBeginCommitRollback.cpp:1.11
carob/test/TestBeginCommitRollback.cpp:1.12
--- carob/test/TestBeginCommitRollback.cpp:1.11 Thu Jan 12 18:05:05 2006
+++ carob/test/TestBeginCommitRollback.cpp Tue Jan 24 18:54:51 2006
@@ -25,6 +25,7 @@

#include "Common.hpp"
#include "Request.hpp"
+#include "RequestWithResultSetParameters.hpp"

using std::wstring;


<Prev in Thread] Current Thread [Next in Thread>
Google Custom Search

Free Magazines

Cisco News
Receive a free quarterly e-newsletter with exclusive articles on how Cisco IT uses its own products and solutions to enable the business.
subscribe

Systems Management News, the newspaper for IT systems administration and data center managers! Each issue of Systems Management News is chock-full of news and analysis to help you understand what's happening in your field.
subscribe

The Enterprise Newsweekly eWeek is the essential technology information source for builders of e-business.
subscribe

Oracle Magazine Oracle Magazine contains technology strategy articles, sample code, tips, Oracle and partner news, how to articles for developers and DBAs, and more. Oracle (NASDAQ: ORCL) is the world's largest enterprise software company.
subscribe

Total Telecom Total Telecom is "The Economist of the communications industry".
subscribe

Navigation

Home | advertise | OSDir is an inevitable website. super tiny logo
Index: carob/include/SQLDataSerialization.hpp
diff -u carob/include/SQLDataSerialization.hpp:1.7
carob/include/SQLDataSerialization.hpp:1.8
--- carob/include/SQLDataSerialization.hpp:1.7 Fri Dec 2 15:53:07 2005
+++ carob/include/SQLDataSerialization.hpp Tue Jan 24 18:54:51 2006
@@ -1,6 +1,6 @@
/*
* Sequoia: Database clustering technology.
- * Copyright (C) 2005 Emic Networks
+ * Copyright (C) 2005-2006 Continuent, Inc.
* Contact: sequoia-NAAfj4rwCWAYtQj7fl1lsA@xxxxxxxxxxxxxxxx
*
* Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,14 +22,13 @@
#ifndef SQLDATASERIALIZATION_H_
#define SQLDATASERIALIZATION_H_

-#include <map>
-
-#include "TypeTag.hpp"
+#include "CarobException.hpp"

namespace CarobNS {

-//forward this union which is declared in Common.hpp
-union ResultSetDataType;
+class TypeTag;
+class DriverSocket;
+union ResultSetDataType; //declared in Common.hpp

/** To ease and simplify deserialization function pointers declaration */
typedef ResultSetDataType (*deserializerPtr)(const DriverSocket&);
@@ -42,12 +41,12 @@
{
public:
/**
* To get the deserializer, give the object type and you'll
* get the function.
* @throws NotImplementedException if the deserialization for the givern
* type is not implemented yet
*/
- static deserializerPtr getDeserializer(TypeTag)
+ static deserializerPtr getDeserializer(TypeTag ttPrm)
throw (NotImplementedException, UnexpectedException);
};
@@ -42,12 +41,12 @@
public:
/**
- * To get the deserializer, give the object type and you'll
- * get the function.
- * @throws NotImplementedException if the deserialization for the givern
- * type is not implemented yet
+ * To get the deserializer, give the object type and you'll get the function.
+ * @param ttPrm type of object to be deserialized
+ * @throws NotImplementedException if the deserialization for the given type
+ * is not implemented yet
*/
